@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2011 - 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -6,26 +6,30 @@
 #define DBUSLOCKFRONTSERVICE_H
 
 #include "dbuslockagent.h"
+
 #include <QDBusAbstractAdaptor>
-#include <QtCore/QObject>
-#include <QtDBus/QtDBus>
 
 QT_BEGIN_NAMESPACE
 class QByteArray;
 template<class T> class QList;
 template<class Key, class Value> class QMap;
 class QString;
-class QStringList;
 class QVariant;
 QT_END_NAMESPACE
 
+const QString lockFrontService = "org.deepin.dde.LockFront1";
+
 /*
- * Proxy class for interface org.deepin.dde.LockFront1
+ * Proxy class for interface com.deepin.dde.lockFront
  */
 class DBusLockFrontService: public QDBusAbstractAdaptor
 {
     Q_OBJECT
+#ifndef ENABLE_DSS_SNIPE
+    Q_CLASSINFO("D-Bus Interface", "com.deepin.dde.lockFront")
+#else
     Q_CLASSINFO("D-Bus Interface", "org.deepin.dde.LockFront1")
+#endif
 
 public:
     explicit DBusLockFrontService(DBusLockAgent *parent);
@@ -34,7 +38,11 @@ public:
     inline DBusLockAgent *parent() const
     { return static_cast<DBusLockAgent *>(QObject::parent()); }
 
-public:// PROPERTIES
+public: // PROPERTIES
+    Q_PROPERTY(bool Visible READ visible)
+
+    bool visible() const;
+
 public Q_SLOTS:// METHODS
     void Show();
     void ShowUserList();
