@@ -80,6 +80,25 @@
         <translation>Iris ID is vergrendeld - voer je wachtwoord in</translation>
     </message>
 </context>
+<context>
+    <name>AuthPasskey</name>
+    <message>
+        <source>Please plug in the security key</source>
+        <translation>Plug de beveiligingssleutel in</translation>
+    </message>
+    <message>
+        <source>Verification successful</source>
+        <translation>Verificatie gelukt</translation>
+    </message>
+    <message>
+        <source>Verification failed</source>
+        <translation>Verificatie mislukt</translation>
+    </message>
+    <message>
+        <source>Identifying the security key</source>
+        <translation>Bezig met identificeren van sleutel…</translation>
+    </message>
+</context>
 <context>
     <name>AuthPassword</name>
     <message>
@@ -166,7 +185,7 @@
     </message>
     <message numerus="yes">
         <source>Please try again %n minute(s) later</source>
-        <translation><numerusform>Probeer het over %n minuut</numerusform><numerusform>Probeer het over %n minuten opnieuw</numerusform></translation>
+        <translation><numerusform>Probeer het over %n minuut opnieuw</numerusform><numerusform>Probeer het over %n minuten opnieuw</numerusform></translation>
     </message>
     <message>
         <source>Please try again 1 minute later</source>
@@ -188,78 +207,23 @@
         <translation><numerusform>Je wachtwoord vervalt over %n dag - wijzig het op tijd!</numerusform><numerusform>Je wachtwoord vervalt over %n dagen - wijzig het op tijd!</numerusform></translation>
     </message>
     <message>
-        <source>Your password has expired. Please contact the administrator to change it.</source>
+        <source>Password expired, please change</source>
+        <translation>Je wachtwoord is verlopen - wijzig het</translation>
+    </message>
+    <message>
+        <source>Your password has expired. Please contact the administrator to change it</source>
         <translation>Je wachtwoord is verlopen. Neem contact op met de beheerder om het te wijzigen.</translation>
     </message>
     <message>
-        <source>Your password has expired. Please change it.</source>
-        <translation>Je wachtwoord is verlopen - wijzig het.</translation>
+        <source>Terminal locked, please contact administrator</source>
+        <translation>De terminal is vergrendeld - neem contact op met de systeembeheerder</translation>
     </message>
 </context>
 <context>
-    <name>ChangePasswordWidget</name>
+    <name>DeepinAuthFramework</name>
     <message>
-        <source>Your password has expired. Please change it and log in again.</source>
-        <translation>Je wachtwoord is verlopen - wijzig het en meld je dan opnieuw aan.</translation>
-    </message>
-    <message>
-        <source>Save</source>
-        <translation>Opslaan</translation>
-    </message>
-    <message>
-        <source>Old password</source>
-        <translation>Oud wachtwoord</translation>
-    </message>
-    <message>
-        <source>New password</source>
-        <translation>Nieuw wachtwoord</translation>
-    </message>
-    <message>
-        <source>Repeat new password</source>
-        <translation>Herhaal wachtwoord</translation>
-    </message>
-    <message>
-        <source>Password hint (Optional)</source>
-        <translation>Wachtwoordhint (optioneel)</translation>
-    </message>
-    <message>
-        <source>Passwords do not match</source>
-        <translation>De wachtwoorden komen niet overeen</translation>
-    </message>
-    <message>
-        <source>The hint is visible to all users. Do not include the password here.</source>
-        <translation>Deze hint is zichtbaar voor alle gebruikers, dus zet hier NIET je wachtwoord neer.</translation>
-    </message>
-    <message>
-        <source>New password should differ from the current one</source>
-        <translation>Het nieuwe wachtwoord moet verschillen van het huidige wachtwoord</translation>
-    </message>
-    <message>
-        <source>Password changed</source>
-        <translation>Het wachtwoord is gewijzigd</translation>
-    </message>
-    <message>
-        <source>Wrong password</source>
-        <translation>Onjuist wachtwoord</translation>
-    </message>
-</context>
-<context>
-    <name>ControlWidget</name>
-    <message>
-        <source>Desktop Environment and Display Protocol</source>
-        <translation>Werkomgeving en vensterprotocol</translation>
-    </message>
-    <message>
-        <source>Keyboard Layout</source>
-        <translation>Toetsenbordindeling</translation>
-    </message>
-    <message>
-        <source>Switch User</source>
-        <translation>Andere gebruiker</translation>
-    </message>
-    <message>
-        <source>Power</source>
-        <translation>Energie</translation>
+        <source>Wrong Password</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -279,6 +243,17 @@
         <source>Cancel</source>
         <translation>Annuleren</translation>
     </message>
+    <message>
+        <source>The reason of inhibit.</source>
+        <translation>De afsluitreden.</translation>
+    </message>
+</context>
+<context>
+    <name>LighterGreeter</name>
+    <message>
+        <source>Standard Mode</source>
+        <translation>Standaardmodus</translation>
+    </message>
 </context>
 <context>
     <name>LockContent</name>
@@ -295,7 +270,7 @@
     <name>LockWorker</name>
     <message>
         <source>Fingerprint verification timed out, please enter your password manually</source>
-        <translation>De vingerafdrukverificatie is verlopen. Voer je wachtwoord handmatig in.</translation>
+        <translation>Vingerafdrukauthenticatie verlopen - voer je wachtwoord handmatig in</translation>
     </message>
     <message>
         <source>Failed to match fingerprint</source>
@@ -318,69 +293,10 @@
     </message>
 </context>
 <context>
-    <name>PasswordLevelWidget</name>
+    <name>SessionWidget</name>
     <message>
-        <source>Weak</source>
-        <translation>Zwak</translation>
-    </message>
-    <message>
-        <source>Medium</source>
-        <translation>Redelijk</translation>
-    </message>
-    <message>
-        <source>Strong</source>
-        <translation>Sterk</translation>
-    </message>
-</context>
-<context>
-    <name>PwqualityManager</name>
-    <message>
-        <source>Password cannot be empty</source>
-        <translation>Voer een wachtwoord in</translation>
-    </message>
-    <message>
-        <source>Password must have at least %1 characters</source>
-        <translation>Het wachtwoord moet minimaal %1 tekens bevatten</translation>
-    </message>
-    <message>
-        <source>Password must be no more than %1 characters</source>
-        <translation>Het wachtwoord mag niet langer zijn dan %1 tekens</translation>
-    </message>
-    <message>
-        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
-        <translation>Het wachtwoord mag alleen Nederlandstalige letters (hoofdlettergevoelig), cijfers of speciale tekens (~!@#$%^&amp;*()[]{}\|/?,.&lt;&gt;) bevatten</translation>
-    </message>
-    <message>
-        <source>No more than %1 palindrome characters please</source>
-        <translation>Maximaal %1 palindroomtekens</translation>
-    </message>
-    <message>
-        <source>No more than %1 monotonic characters please</source>
-        <translation>Maximaal %1 monotone tekens</translation>
-    </message>
-    <message>
-        <source>No more than %1 repeating characters please</source>
-        <translation>Maximaal %1 dezelfde tekens</translation>
-    </message>
-    <message>
-        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
-        <translation>Het wachtwoord moet hoofdletters, kleine letters, getallen en speciale tekens bevatten (~!@#$%^&amp;*()[]{}\|/?,.&lt;&gt;)</translation>
-    </message>
-    <message>
-        <source>Password must not contain more than 4 palindrome characters</source>
-        <translation>Het wachtwoord mag niet meer dan 4 palindroomtekens bevatten</translation>
-    </message>
-    <message>
-        <source>Do not use common words and combinations as password</source>
-        <translation>Het wachtwoord mag geen algemene woorden of samenstellingen bevatten</translation>
-    </message>
-    <message>
-        <source>Create a strong password please</source>
-        <translation>Stel een sterk wachtwoord samen</translation>
-    </message>
-    <message>
-        <source>It does not meet password rules</source>
-        <translation>Het wachtwoord voldoet niet aan de vereisten</translation>
+        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
+        <translation>Je kunt de Wayland-modus niet gebruiken omdat je het hoogste beveiligingsniveau hebt ingeschakeld. Schakel dit niveau uit in het beveiligingscentrum en probeer het opnieuw.</translation>
     </message>
 </context>
 <context>
@@ -409,13 +325,21 @@
         <source>Log out</source>
         <translation>Afmelden</translation>
     </message>
+    <message>
+        <source>Switch user</source>
+        <translation>Andere gebruiker</translation>
+    </message>
     <message>
         <source>Switch system</source>
         <translation>Ander systeem</translation>
     </message>
     <message>
-        <source>Switch user</source>
-        <translation>Andere gebruiker</translation>
+        <source>Update and Shut Down</source>
+        <translation>Bijwerken en afsluiten</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>Bijwerken en herstarten</translation>
     </message>
 </context>
 <context>
@@ -426,25 +350,52 @@
     </message>
 </context>
 <context>
-    <name>UserListPopupWidget</name>
+    <name>UdcpMFALoginWidget</name>
     <message>
-        <source>Standard User</source>
-        <translation>Standaardgebruiker</translation>
+        <source>发送验证码</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <source>Administrator</source>
-        <translation>Beheerder</translation>
+        <source>请输入手机号</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <source>Other Users</source>
-        <translation>Andere gebruikers</translation>
+        <source>请输入验证码</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>获取验证码</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
-    <name>VirtualKeyboardModule</name>
+    <name>UpdateWorker</name>
     <message>
-        <source>Onboard</source>
-        <translation>Onboard</translation>
+        <source>Update</source>
+        <translation>Bijwerken</translation>
+    </message>
+    <message>
+        <source>Please plug in and then install updates.</source>
+        <translation>Sluit de netstroomadapter aan alvorens de updates te installeren.</translation>
+    </message>
+</context>
+<context>
+    <name>UsersWithTheSameName</name>
+    <message>
+        <source>Return</source>
+        <translation>Terug</translation>
+    </message>
+    <message>
+        <source>Please select the account for login</source>
+        <translation>Kies het account waarop je wilt inloggen</translation>
+    </message>
+    <message>
+        <source>Local Account</source>
+        <translation>Lokaal account</translation>
+    </message>
+    <message>
+        <source>Domain Account</source>
+        <translation>Domeinaccount</translation>
     </message>
 </context>
 <context>
@@ -505,6 +456,33 @@
         <source>Are you sure you want to log out?</source>
         <translation>Weet je zeker dat je wilt afmelden?</translation>
     </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation>Bijwerken en afsluiten</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>Bijwerken en herstarten</translation>
+    </message>
+    <message>
+        <source>Closing the programs and shutting down, please wait...</source>
+        <translation>Bezig met afsluiten van programma&apos;s en computer…</translation>
+    </message>
+    <message>
+        <source>Closing the programs and rebooting, please wait...</source>
+        <translation>Bezig met afsluiten van programma&apos;s en opnieuw opstarten…</translation>
+    </message>
+    <message>
+        <source>Closing the programs and logging out, please wait...</source>
+        <translation>Bezig met afsluiten van programma&apos;s en uitloggen…</translation>
+    </message>
+</context>
+<context>
+    <name>dss::module::AssistLoginWidget</name>
+    <message>
+        <source>Automatic login</source>
+        <translation>Automatisch aanmelden</translation>
+    </message>
 </context>
 <context>
     <name>dss::module::NetworkModule</name>
